@@ -14,11 +14,4 @@ class StopStep(Enum):
 
 class ImplementationStep(Enum):
     PLACE = auto()
-    ROUTE = auto()
-
-
-class RegressionModel(Enum):
-    KERNEL_RIDGE = auto()
-    STREAM_LEARNING_ISOUP = auto()
-    STREAM_LEARNING_STACKED = auto()
-
+    ROUTE = auto()
\ No newline at end of file
